Name:           ocaml-ocplib-endian
Version:        1.2
Release:        %mkrel 1
Summary:        Functions to read/write int16/32/64 from strings, bigarrays
Group:          Development/OCaml

%global libname ocplib-endian

# License is LGPL 2.1 with standard OCaml exceptions
License:        LGPLv2+ with exceptions
URL:            https://github.com/OCamlPro/ocplib-endian
Source0:        https://github.com/OCamlPro/ocplib-endian/archive/%{version}/ocplib-endian-%{version}.tar.gz

BuildRequires:  ocaml >= 4.02.3
BuildRequires:  ocaml-cppo >= 1.1.0
BuildRequires:  ocaml-dune >= 1.0


%description
Optimised functions to read and write int16/32/64 from strings,
bytes and bigarrays, based on primitives added in version 4.01.

The library implements three modules:

EndianString works directly on strings, and provides submodules
BigEndian and LittleEndian, with their unsafe counter-parts;
EndianBytes works directly on bytes, and provides submodules
BigEndian and LittleEndian, with their unsafe counter-parts;
EndianBigstring works on bigstrings (Bigarrays of chars),
and provides submodules BigEndian and LittleEndian, with their
unsafe counter-parts;

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and
signature files for developing applications that use %{name}.

%prep
%autosetup -n %{libname}-%{version}

%build
dune build %{?_smp_mflags}

%install
dune install --destdir=%{buildroot}

# We install the documentation with the doc macro
rm -fr %{buildroot}%{_prefix}/doc

# We do not want the ml files
find %{buildroot}%{_libdir}/ocaml -name \*.ml -delete

%ifarch %{ocaml_native_compiler}
# Add missing executable bits
find %{buildroot}%{_libdir}/ocaml -name \*.cmxs -exec chmod 0755 {} \+
%endif

# The tests currently fail, showing allocation of 54 words for all 3 tests.
# The issue is known, but upstream's remedy does not work with OCaml 4.11.
# See https://github.com/OCamlPro/ocplib-endian/issues/18
#
#%%check
#dune runtest

%files
%license COPYING.txt
%doc README.md CHANGES.md
%dir %{_libdir}/ocaml/%{libname}/
%dir %{_libdir}/ocaml/%{libname}/bigstring/
%{_libdir}/ocaml/%{libname}/*.cma
%{_libdir}/ocaml/%{libname}/*.cmi
%{_libdir}/ocaml/%{libname}/bigstring/*.cma
%{_libdir}/ocaml/%{libname}/bigstring/*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{libname}/*.cmxs
%{_libdir}/ocaml/%{libname}/bigstring/*.cmxs
%endif


%files devel
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{libname}/*.a
%{_libdir}/ocaml/%{libname}/*.cmxa
%{_libdir}/ocaml/%{libname}/*.cmx
%{_libdir}/ocaml/%{libname}/bigstring/*.a
%{_libdir}/ocaml/%{libname}/bigstring/*.cmxa
%{_libdir}/ocaml/%{libname}/bigstring/*.cmx
%endif
%{_libdir}/ocaml/%{libname}/*.mli
%{_libdir}/ocaml/%{libname}/*.cmt
%{_libdir}/ocaml/%{libname}/*.cmti
%{_libdir}/ocaml/%{libname}/bigstring/*.mli
%{_libdir}/ocaml/%{libname}/bigstring/*.cmt
%{_libdir}/ocaml/%{libname}/bigstring/*.cmti
%{_libdir}/ocaml/%{libname}/META
%{_libdir}/ocaml/%{libname}/dune-package
%{_libdir}/ocaml/%{libname}/opam



%changelog
* Sun Oct 09 2022 pterjan <pterjan> 1.2-1.mga9
+ Revision: 1895636
- Update to 1.2

* Thu May 19 2022 pterjan <pterjan> 1.1-4.mga9
+ Revision: 1859108
- Rebuild for OCaml 4.14

* Mon Apr 04 2022 umeabot <umeabot> 1.1-3.mga9
+ Revision: 1843045
- Mageia 9 Mass Rebuild

* Wed Oct 13 2021 tv <tv> 1.1-2.mga9
+ Revision: 1750840
- Rebuild for ocaml 4.13.1

* Wed Mar 03 2021 tv <tv> 1.1-1.mga9
+ Revision: 1696708
- 1.1

* Sun Jan 10 2021 pterjan <pterjan> 1.0-4.mga8
+ Revision: 1670292
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 1.0-3.mga8
+ Revision: 1551585
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 1.0-2.mga8
+ Revision: 1545145
- Mageia 8 Mass Rebuild

* Mon Jan 27 2020 tv <tv> 1.0-1.mga8
+ Revision: 1484097
- new release + reintroduce for ocaml-4.10
- rebuild for new ocaml

* Mon Sep 26 2016 pterjan <pterjan> 0.4-7.mga6
+ Revision: 1056428
- Rebuild for fix in ocaml

* Wed Feb 17 2016 umeabot <umeabot> 0.4-6.mga6
+ Revision: 963857
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.4-5.mga5
+ Revision: 748093
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.4-4.mga5
+ Revision: 683077
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.4-3.mga4
+ Revision: 533932
- Mageia 4 Mass Rebuild

* Sun Sep 08 2013 blue_prawn <blue_prawn> 0.4-2.mga4
+ Revision: 475822
- provide license file

* Sun Sep 08 2013 blue_prawn <blue_prawn> 0.4-1.mga4
+ Revision: 475814
- updated to last version 0.4
- providing the generated api doc

* Sun Jan 13 2013 umeabot <umeabot> 0.3-2.mga3
+ Revision: 361529
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 04 2013 malo <malo> 0.3-1.mga3
+ Revision: 338458
- imported package ocaml-ocplib-endian

